```{include} ../../README.md
```

<!-- Table of Content entries, shown in left sidebar. -->

```{toctree}
:hidden:
:caption: Usage

getting_started
api
```

```{toctree}
:hidden:
:caption: Development

Contributing <https://github.com/cjtu/craterpy/blob/main/CONTRIBUTING.rst>
Code of Conduct <https://github.com/cjtu/craterpy/blob/main/CODE_OF_CONDUCT.md>
GitHub repo <https://github.com/cjtu/craterpy>
```

```{toctree}
:hidden:
:caption: Attribution

Citation <https://zenodo.org/badge/latestdoi/88457986>
License <https://github.com/cjtu/craterpy/blob/main/LICENSE.txt>
```
